@@ -1,7 +1,10 @@
-import openmc_source_plotter as osp
 from openmc_plasma_source import TokamakSource
 
-my_source = TokamakSource(
+# openmc_plasma_source makes use of this package and
+# TokamakSource is a SourceWithPlotting object so it has
+# access to the plotting methods
+
+my_sources = TokamakSource(
     elongation=1.557,
     ion_density_centre=1.09e20,
     ion_density_peaking_factor=1,
@@ -22,6 +25,8 @@ my_source = TokamakSource(
 
 
 # plots the particle energy distribution
-plot = osp.plot_source_position(source=my_source, n_samples=100)
+plot = None
+for source in my_sources:
+    plot = source.plot_source_position(figure=plot)
 
 plot.show()
