@@ -13,7 +13,4 @@ except PackageNotFoundError:
 
 __all__ = ["__version__"]
 
-from .core import plot_source_direction
-from .core import plot_source_energy
-from .core import plot_source_position
-from .core import sample_initial_particles
+from .core import SourceWithPlotting
